netapp_ontap.models.switch_port_remote_port_device API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.switch_port_remote_port_device`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SwitchPortRemotePortDeviceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SwitchPortRemotePortDevice object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `dcn: SwitchPortRemotePortDeviceDcn GET`

    Compute node connected to this port.

  `discovered_name: str GET`

    Raw name of the discovered device.

    Example: stiA400-311

  `node: Node GET`

    The node field of the switch_port_remote_port_device.

  `shelf: SwitchPortRemotePortDeviceShelf GET`

    Shelf connected to this port.